``saltext-redis``: Integrate Salt with Redis
============================================

Salt Extension for interacting with Redis

.. toctree::
  :maxdepth: 2
  :caption: Guides
  :hidden:

  topics/installation

.. toctree::
  :maxdepth: 2
  :caption: Provided Modules
  :hidden:

  ref/cache/index
  ref/engines/index
  ref/modules/index
  ref/pillar/index
  ref/returners/index
  ref/sdb/index
  ref/states/index
  ref/tokens/index

.. toctree::
  :maxdepth: 2
  :caption: Reference
  :hidden:

  changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
